@@ -153,7 +153,7 @@ class CloudFrontToMediaStore(
         :param id: - this is a scope-unique id.
         :param cloud_front_distribution_props: Optional user provided props to override the default props for the CloudFront. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
-        :param existing_media_store_container_obj: Existing instance of mediastore.CfnContainer obejct. Default: - None
+        :param existing_media_store_container_obj: Existing instance of mediastore.CfnContainer object. Default: - None
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
         :param media_store_container_props: Optional user provided props to override the default props for the MediaStore. Default: - Default props are used
         :param response_headers_policy_props: Optional user provided configuration that cloudfront applies to all http responses. Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or ResponseHeadersCorsBehavior to the cloudfront distribution. Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true`` and ResponseSecurityHeadersBehavior is passed. Default: - undefined
@@ -244,7 +244,7 @@ class CloudFrontToMediaStoreProps:
         '''
         :param cloud_front_distribution_props: Optional user provided props to override the default props for the CloudFront. Default: - Default props are used
         :param cloud_front_logging_bucket_props: Optional user provided props to override the default props for the CloudFront Logging Bucket. Default: - Default props are used
-        :param existing_media_store_container_obj: Existing instance of mediastore.CfnContainer obejct. Default: - None
+        :param existing_media_store_container_obj: Existing instance of mediastore.CfnContainer object. Default: - None
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Turning this on will inject default headers and is mutually exclusive with passing custom security headers via the responseHeadersPolicyProps parameter. Default: - true
         :param media_store_container_props: Optional user provided props to override the default props for the MediaStore. Default: - Default props are used
         :param response_headers_policy_props: Optional user provided configuration that cloudfront applies to all http responses. Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or ResponseHeadersCorsBehavior to the cloudfront distribution. Passing a custom ResponseSecurityHeadersBehavior is mutually exclusive with turning on the default security headers via ``insertHttpSecurityHeaders`` prop. Will throw an error if both ``insertHttpSecurityHeaders`` is set to ``true`` and ResponseSecurityHeadersBehavior is passed. Default: - undefined
@@ -303,7 +303,7 @@ class CloudFrontToMediaStoreProps:
     def existing_media_store_container_obj(
         self,
     ) -> typing.Optional[_aws_cdk_aws_mediastore_ceddda9d.CfnContainer]:
-        '''Existing instance of mediastore.CfnContainer obejct.
+        '''Existing instance of mediastore.CfnContainer object.
 
         :default: - None
         '''
